Name

Struct Name 

pub struct Name { /* private fields */ }
identifier or string or CROSS or FULL or INNER or LEFT or NATURAL or OUTER or RIGHT.

Two Names are equal if they refer to the same identifier, regardless of quoting style (e.g. ABORT and "ABORT" are the same identifier).

Implementations

Source

impl Name

pub fn exact(s: String) -> Self

Create name which will have exactly the value of given string (e.g. if s = “"str"” - the name value will contain quotes and translation to SQL will give us “”“str”“”)

pub fn from_bytes(s: &[u8]) -> Self

Parse name from the bytes (e.g. handle quoting and handle escaped quotes)

pub const fn empty() -> Self

pub fn from_string(s: impl AsRef<str>) -> Self

Parse name from the string (e.g. handle quoting and handle escaped quotes)

pub fn as_str(&self) -> &str

Return string value of the name

pub fn as_literal(&self) -> String

Convert value to the string literal (e.g. single-quoted string with escaped single quotes)

pub fn as_ident(&self) -> String

Convert value to the name string (e.g. double-quoted string with escaped double quotes)

pub fn quoted_with(&self, quote: char) -> bool

Checks if a name represents a quoted string that should get fallback behavior Need to detect legacy conversion of double quoted keywords to string literals (see https://sqlite.org/lang_keywords.html)

Also, used to detect string literals in PRAGMA cases

pub const fn quoted(&self) -> bool